[object Object]

← back to Exo

downgrade grpc to 1.67.0. waiting for fix https://github.com/grpc/grpc/commit/bd8f8a86e06df9d5cf6bc36ba77981d621b80b44

30c3f58a0000313198337a859a2fa6e76137b709 · 2025-02-28 21:25:11 +0000 · Alex Cheema

Files touched

Diff

commit 30c3f58a0000313198337a859a2fa6e76137b709
Author: Alex Cheema <alexcheema123@gmail.com>
Date:   Fri Feb 28 21:25:11 2025 +0000

    downgrade grpc to 1.67.0. waiting for fix https://github.com/grpc/grpc/commit/bd8f8a86e06df9d5cf6bc36ba77981d621b80b44
---
 exo/networking/grpc/node_service_pb2.py      | 6 +++---
 exo/networking/grpc/node_service_pb2_grpc.py | 2 +-
 setup.py                                     | 4 ++--
 3 files changed, 6 insertions(+), 6 deletions(-)

diff --git a/exo/networking/grpc/node_service_pb2_grpc.py b/exo/networking/grpc/node_service_pb2_grpc.py
index a683791d..ac12e2f7 100644
--- a/exo/networking/grpc/node_service_pb2_grpc.py
+++ b/exo/networking/grpc/node_service_pb2_grpc.py
@@ -5,7 +5,7 @@ import warnings
 
 from . import node_service_pb2 as node__service__pb2
 
-GRPC_GENERATED_VERSION = '1.68.0'
+GRPC_GENERATED_VERSION = '1.67.0'
 GRPC_VERSION = grpc.__version__
 _version_not_supported = False
 
diff --git a/setup.py b/setup.py
index 45824329..e9431ca4 100644
--- a/setup.py
+++ b/setup.py
@@ -9,8 +9,8 @@ install_requires = [
   "aiohttp==3.10.11",
   "aiohttp_cors==0.7.0",
   "aiofiles==24.1.0",
-  "grpcio==1.70.0",
-  "grpcio-tools==1.70.0",
+  "grpcio==1.67.0",
+  "grpcio-tools==1.67.0",
   "Jinja2==3.1.4",
   "numpy==2.0.0",
   "nuitka==2.5.1",

← 4081305e adjust grpc settings, ensure connected before sending any gr  ·  back to Exo  ·  remove dead links in README 013d2573 →
diff --git a/exo/networking/grpc/node_service_pb2.py b/exo/networking/grpc/node_service_pb2.py
index 988974db..9a83380d 100644
--- a/exo/networking/grpc/node_service_pb2.py
+++ b/exo/networking/grpc/node_service_pb2.py
@@ -2,7 +2,7 @@
 # Generated by the protocol buffer compiler.  DO NOT EDIT!
 # NO CHECKED-IN PROTOBUF GENCODE
 # source: node_service.proto
 # Protobuf Python Version: 5.28.1
 """Generated protocol buffer code."""
 from google.protobuf import descriptor as _descriptor
 from google.protobuf import descriptor_pool as _descriptor_pool
@@ -12,8 +12,8 @@ from google.protobuf.internal import builder as _builder
 _runtime_version.ValidateProtobufRuntimeVersion(
     _runtime_version.Domain.PUBLIC,
     5,
-    28,
-    1,
+    27,
+    2,
     '',
     'node_service.proto'
 )
@@ -2,7 +2,7 @@
 # NO CHECKED-IN PROTOBUF GENCODE
 # source: node_service.proto
-# Protobuf Python Version: 5.28.1
+# Protobuf Python Version: 5.27.2
 """Generated protocol buffer code."""
 from google.protobuf import descriptor as _descriptor